==> phpnuke-5.5.tgz: www/phpnuke/html/modules/News/language/lang-thai.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","");
define("_URL","URL");
define("_PRINTER","˹͡Ѻͧ");
define("_FRIEND","ͧ͹ҹ");
define("_YOURNAME","ͤس");
define("_OK","ŧ!");
define("_RELATED","§Ǣͧ");
define("_MOREABOUT","");
define("_NEWSBY","ʹ͢");
define("_MOSTREAD","ͧҹҡش");
define("_READMORE","յ...");
define("_BYTESMORE","bytes more");
define("_COMMENTSQ","ʴ?");
define("_COMMENT","ͤԴ");
define("_CONFIGURE","ûѺ¹ҵԴ");
define("_LOGINCREATE","ѤҪԡ");
define("_THRESHOLD","ṹ");
define("_NOCOMMENTS","դ");
define("_NESTED","͡");
define("_FLAT","ʴǵç");
define("_THREAD","ʴдѺ");
define("_OLDEST","ҡ͹");
define("_NEWEST","͹");
define("_HIGHEST","§ṹ٧͹");
define("_COMMENTSWARNING","Դ繷ʴ繢ͧ繢ͧŧС. ҧ䫵 ѺԴͺҹ.");
define("_SCORE","ṹ:");
define("_USERINFO","ż");
define("_READREST","ҹ繵...");
define("_REPLY","ͺѺ");
define("_REPLYMAIN","Ԩó");
define("_NOSUBJECT","ѧժͧ");
define("_NOANONCOMMENTS","ŧ¹ Էʴ , ô <a href=\"modules.php?name=Your_Account\">ŧ¹</a>");
define("_PARENT","Ǣ");
define("_ROOT","Root");
define("_UCOMMENT","");
define("_ALLOWEDHTML"," HTML ö:");
define("_POSTANON","ѹ֡ ʧ͡");
define("_EXTRANS","Extrans (¹ html tags ѡø)");
define("_HTMLFORMATED","ѹ֡ HTML");
define("_PLAINTEXT","Ż");
define("_ONN","on...");
define("_SUBJECT","ͧ");
define("_COMMENTREPLY","繵ͤ͢");
define("_COMREPLYPRE","ʴ繷ж١任С");
define("_NOTRIGHT","պҧ觺ҧҧԴá 㹡觤");
define("_SENDAMSG","觢͡");
define("_YOUSENDSTORY","سѧͧѧ");
define("_TOAFRIEND","ѧ͹к:");
define("_FYOURNAME","ͤس:");
define("_FYOUREMAIL","س:");
define("_FFRIENDNAME","͹س:");
define("_FFRIENDEMAIL","͹س:");
define("_INTERESTING","ʹ㨷 ");
define("_HELLO","ʴ");
define("_YOURFRIEND","س");
define("_CONSIDERED","觺Ԩóͧ仹");
define("_FDATE","ѹ:");
define("_FTOPIC","Ǣ:");
define("_YOUCANREAD","سöҹʹ");
define("_FSTORY","ͧ");
define("_HASSENT","١");
define("_THANKS","º .......ͺس!");
define("_RECOMMEND","й ͡");
define("_PDATE","ѹ");
define("_PTOPIC","Ǣ:");
define("_COMESFROM","Ҩҡ");
define("_THEURL","URL Ѻͧ:");
define("_PREVIEW","ͧʴźҾ");
define("_NEWUSER","Ҫԡ");
define("_OPTIONS","Options");
define("_REFRESH","ʴ");
define("_ADD","Add");
define("_NOCOMMENTSACT","Sorry, Comments are not available for this article.");
define("_ARTICLEPOLL","Article's Poll");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/News/language/lang-thai.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","");
define("_URL","URL");
define("_PRINTER","˹͡Ѻͧ");
define("_FRIEND","ͧ͹ҹ");
define("_YOURNAME","ͤس");
define("_OK","ŧ!");
define("_RELATED","§Ǣͧ");
define("_MOREABOUT","");
define("_NEWSBY","ʹ͢");
define("_MOSTREAD","ͧҹҡش");
define("_READMORE","յ...");
define("_BYTESMORE","bytes more");
define("_COMMENTSQ","ʴ?");
define("_COMMENT","ͤԴ");
define("_CONFIGURE","ûѺ¹ҵԴ");
define("_LOGINCREATE","ѤҪԡ");
define("_THRESHOLD","ṹ");
define("_NOCOMMENTS","դ");
define("_NESTED","͡");
define("_FLAT","ʴǵç");
define("_THREAD","ʴдѺ");
define("_OLDEST","ҡ͹");
define("_NEWEST","͹");
define("_HIGHEST","§ṹ٧͹");
define("_COMMENTSWARNING","Դ繷ʴ繢ͧ繢ͧŧС. ҧ䫵 ѺԴͺҹ.");
define("_SCORE","ṹ:");
define("_USERINFO","ż");
define("_READREST","ҹ繵...");
define("_REPLY","ͺѺ");
define("_REPLYMAIN","Ԩó");
define("_NOSUBJECT","ѧժͧ");
define("_NOANONCOMMENTS","ŧ¹ Էʴ , ô <a href=\"modules.php?name=Your_Account\">ŧ¹</a>");
define("_PARENT","Ǣ");
define("_ROOT","Root");
define("_UCOMMENT","");
define("_ALLOWEDHTML"," HTML ö:");
define("_POSTANON","ѹ֡ ʧ͡");
define("_EXTRANS","Extrans (¹ html tags ѡø)");
define("_HTMLFORMATED","ѹ֡ HTML");
define("_PLAINTEXT","Ż");
define("_ONN","on...");
define("_SUBJECT","ͧ");
define("_COMMENTREPLY","繵ͤ͢");
define("_COMREPLYPRE","ʴ繷ж١任С");
define("_NOTRIGHT","պҧ觺ҧҧԴá 㹡觤");
define("_SENDAMSG","觢͡");
define("_YOUSENDSTORY","سѧͧѧ");
define("_TOAFRIEND","ѧ͹к:");
define("_FYOURNAME","ͤس:");
define("_FYOUREMAIL","س:");
define("_FFRIENDNAME","͹س:");
define("_FFRIENDEMAIL","͹س:");
define("_INTERESTING","ʹ㨷 ");
define("_HELLO","ʴ");
define("_YOURFRIEND","س");
define("_CONSIDERED","觺Ԩóͧ仹");
define("_FDATE","ѹ:");
define("_FTOPIC","Ǣ:");
define("_YOUCANREAD","سöҹʹ");
define("_FSTORY","ͧ");
define("_HASSENT","١");
define("_THANKS","º .......ͺس!");
define("_RECOMMEND","й ͡");
define("_PDATE","ѹ");
define("_PTOPIC","Ǣ:");
define("_COMESFROM","Ҩҡ");
define("_THEURL","URL Ѻͧ:");
define("_PREVIEW","ͧʴźҾ");
define("_NEWUSER","Ҫԡ");
define("_OPTIONS","Options");
define("_REFRESH","ʴ");
define("_ADD","Add");
define("_NOCOMMENTSACT","Sorry, Comments are not available for this article.");
define("_ARTICLEPOLL","Article's Poll");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>
